Community meetings
==================

LMCache hosts regular community meetings to discuss updates, address new feature requests, 
and feedback from the community. If you are interested in contributing to the LMCache projects
(core LMCache or Production Stack), we encourage you to join the meetings.

Meeting schedule
-----------------
The LMCache community meetings held separately for each project: 

- LMCache - `Github <https://github.com/LMCache/LMCache/>`__
- Production Stack - `Github <https://github.com/vllm-project/production-stack>`__

LMCache Project
++++++++++++++++

The LMCache community meeting is held every week at alternating times, first time slot is from 
**9:00-9:30 AM PT** and the second time slot is from **6:30-7:00 PM PT** on **Tuesdays**. These 
time slots are designed to accommodate different time zones and schedules of the community members and we alternate
between the two time slots every week.

Please find the meeting invite link below:

- **Meeting link**: `Zoom link <https://uchicago.zoom.us/j/6603596916?pwd=Z1E5MDRWUSt2am5XbEt4dTFkNGx6QT09>`_
- **Calendar Invite**: 
    .. raw:: html

        <ul>
            <li>Morning slot <a href="https://drive.google.com/file/d/15Xz8-LtpBQ5QgR7KrorOOyfuohCFQmwn/view?usp=sharing">Google Calendar</a></li>
            <li>Evening slot <a href="https://drive.google.com/file/d/1WMZNFXV24kWzprDjvO-jQ7mOY7whqEdG/view?usp=sharing">Google Calendar</a></li>
        </ul>
- **Slack Channel**: `#lmcache <https://join.slack.com/t/lmcacheworkspace/shared_invite/zt-2viziwhue-5Amprc9k5hcIdXT7XevTaQ>`_

Production Stack Project
+++++++++++++++++++++++++

The Production Stack community meeting is held every week on **Tuesdays from 6:00-6:30 PM PT**.
Please find the meeting invite link below:

- **Meeting link**: `Zoom link <https://uchicago.zoom.us/j/6603596916?pwd=Z1E5MDRWUSt2am5XbEt4dTFkNGx6QT09>`_
- **Calendar Invite**: `Google Calendar <https://drive.google.com/file/d/1iKpFrt-grVZSIbIXpnVlZyEvADcxLMj_/view?usp=sharing>`_
- **Slack Channel**: `#production-stack <https://vllm-dev.slack.com/archives/C089SMEAKRA>`_


.. note:: 
    The Zoom meeting link is the same for both LMCache and Production Stack community meetings. 
    Meeting notes are available here: `Meeting notes <https://docs.google.com/document/d/1vX0g2q3j4x5m7J6z8Q9Gk4Z5l7f3K8h0nqYwW1a2c4o/edit?usp=sharing>`_.
